@@ -26,6 +26,25 @@ def setCompile(cfg):
     compile_list(sdir,tdir)
     pass
 
+def setVersionOnPythonPackage(root = "./",major = 1):
+    pattern = "__version__ = .*$"
+    filename = "__init__.py"
+    now = datetime.datetime.now()
+    for r,ds,fs in os.walk(root):
+        if filename in fs:
+            print("set __init__ Version at path {}".format(r))
+            file = open(os.path.join(r,filename),"r")
+            info = file.read()
+            file.close()
+            
+            
+            ver = "__version__ = {}.{}".format(major,datetime.datetime.strftime(now,'%y.%m%d.%H%M'))
+            info = re.sub(pattern,ver,info)
+            
+            file = open(os.path.join(r,filename),"w")
+            file.write(info)
+            file.close()
+
 
 def setVersionOnpy():
     if not os.path.exists(r"./setup.py"):
@@ -52,7 +71,7 @@ def setCSharpVersion(root = "./",major = 1):
     pattern0 = "([1-9])(.[0-9])(.[0-9])(.[0-9])"
     filename = "AssemblyInfo.cs"
     now = datetime.datetime.now()
-    for r,ds,fs in os.walk("./"):
+    for r,ds,fs in os.walk(root):
         if filename in fs:
             print("setC#Version at path {}".format(r))
             file = open(os.path.join(r,filename),"r")
@@ -98,6 +117,7 @@ def push2git():
     print("start set config process")
     #setVersion(config)
     setVersionOnpy()
+    setVersionOnPythonPackage()
     setCSharpVersion()
     repo = getRepo()
     commit(repo)
