@@ -68,7 +68,7 @@ def showHelp():
     print("divide dataset proportionately,ignore formatter")
     print('-'*20)
     print("param:")
-    print("\t1st ratio \t:\t,such as 7:3,1:1:1.")
+    print("\t1st ratio \t:\tsuch as 7:3,1:1:1.")
     print("\t2nd [seed][17] \t:\t divide randomly with seed,default 17")
     print('-'*20)
 
